Module aabb

Module aabb 

Functions

aabb_ray_cast
Ray cast an AABB. Radius is not handled. (b2AABB_RayCast)
enlarge_aabb
Enlarge a to contain b. (b2EnlargeAABB)
offset_aabb
Translate a relative AABB into world space, rounding outward so the float box always contains the true box far from the origin. (b2OffsetAABB)
perimeter
Get the surface area of an AABB (the perimeter length). (b2Perimeter)