pub struct BodySim {Show 16 fields
pub transform: WorldTransform,
pub center: Pos,
pub rotation0: Rot,
pub center0: Pos,
pub local_center: Vec2,
pub force: Vec2,
pub torque: f32,
pub inv_mass: f32,
pub inv_inertia: f32,
pub min_extent: f32,
pub max_extent: f32,
pub linear_damping: f32,
pub angular_damping: f32,
pub gravity_scale: f32,
pub body_id: i32,
pub flags: u32,
}Expand description
Body simulation data used for integration of position and velocity. Transform data used for collision and solver preparation. (b2BodySim)
Fields
transform: WorldTransformtransform for body origin, double translation in large world mode
center: Poscenter of mass position in world space
rotation0: Rotprevious rotation and COM for TOI
center0: Poslocal_center: Vec2location of center of mass relative to the body origin
force: Vec2torque: f32inv_mass: f32inverse mass and inertia
inv_inertia: f32min_extent: f32max_extent: f32linear_damping: f32angular_damping: f32gravity_scale: f32body_id: i32Index of Body
flags: u32body_flags bits