BodyState

Struct BodyState 

pub struct BodyState {
    pub linear_velocity: Vec2,
    pub angular_velocity: f32,
    pub flags: u32,
    pub delta_position: Vec2,
    pub delta_rotation: Rot,
}
Body state, designed for fast conversion to and from SIMD via scatter-gather. Only awake dynamic and kinematic bodies have a body state. Used in the performance critical constraint solver. (b2BodyState, 32 bytes)

The solver operates on the body state. The body state array does not hold static bodies; their delta rotation is identity via a dummy state.

Fields

linear_velocity: Vec2angular_velocity: f32flags: u32

body_flags bits. Important flags: locking, dynamic.

delta_position: Vec2

Using delta position reduces round-off error far from the origin

delta_rotation: Rot

Using delta rotation because the solver cannot access the full rotation on static bodies and must use zero delta rotation (c,s) = (1,0)