Module broad_phase

Module broad_phase 

Structs

BroadPhase
The broad-phase is used for computing pairs and performing volume queries and ray casts. It does not persist pairs; it reports potentially new pairs. It is up to the client to consume the new pairs and to track subsequent overlap. (b2BroadPhase)

Functions

proxy_id
(B2_PROXY_ID)
proxy_key
(B2_PROXY_KEY)
proxy_type
(B2_PROXY_TYPE)
update_broad_phase_pairs
Find new proxy pairs for everything in the move buffer and create their contacts, in deterministic move-array order. Also rebuilds the dynamic and kinematic trees and clears the move buffer. (b2UpdateBroadPhasePairs — serial port of b2FindPairsTask/b2UpdateTreesTask)