BroadPhase

Struct BroadPhase 

pub struct BroadPhase {
    pub trees: [DynamicTree; 3],
    pub moved_proxies: [BitSet; 3],
    pub move_array: Vec<i32>,
    pub pair_set: HashSet,
}
The broad-phase is used for computing pairs and performing volume queries and ray casts. It does not persist pairs; it reports potentially new pairs. It is up to the client to consume the new pairs and to track subsequent overlap. (b2BroadPhase)

Fields

trees: [DynamicTree; 3]moved_proxies: [BitSet; 3]

Per body-type bit sets indexed by proxyId, marking proxies moved this step. Paired with move_array which preserves deterministic insertion order for pair queries.

move_array: Vec<i32>pair_set: HashSet

Tracks shape pairs that have a Contact.

Implementations

Source

impl BroadPhase

pub fn new(capacity: &Capacity) -> BroadPhase

(b2CreateBroadPhase)

pub fn destroy(&mut self)

(b2DestroyBroadPhase)

pub fn buffer_move(&mut self, query_proxy: i32)

This triggers new contact pairs to be created. Must be called in deterministic order. (static inline b2BufferMove)

pub fn create_proxy( &mut self, proxy_type_: BodyType, aabb: Aabb, category_bits: u64, shape_index: i32, force_pair_creation: bool, ) -> i32

(b2BroadPhase_CreateProxy)

pub fn destroy_proxy(&mut self, proxy_key: i32)

(b2BroadPhase_DestroyProxy)

pub fn move_proxy(&mut self, proxy_key: i32, aabb: Aabb)

(b2BroadPhase_MoveProxy)

pub fn enlarge_proxy(&mut self, proxy_key: i32, aabb: Aabb)

(b2BroadPhase_EnlargeProxy)

pub fn shape_index(&self, proxy_key: i32) -> i32

(b2BroadPhase_GetShapeIndex)

pub fn test_overlap(&self, proxy_key_a: i32, proxy_key_b: i32) -> bool

(b2BroadPhase_TestOverlap)

pub fn validate(&self)

(b2ValidateBroadphase)

pub fn validate_no_enlarged(&self)

(b2ValidateNoEnlarged — C compiles the body under B2_ENABLE_VALIDATION; here the check runs in debug builds only)

pub fn validate_moved_proxies(&self)

(b2ValidateMovedProxies — C compiles the body under B2_ENABLE_VALIDATION; here the whole check runs in debug builds only)