pub struct CastOutput {
pub normal: Vec2,
pub point: Vec2,
pub fraction: f32,
pub iterations: i32,
pub hit: bool,
}Expand description
Low level ray cast or shape cast output data. The hit point is in the local or relative frame of the input. Returns a zero fraction and normal in the case of initial overlap. (b2CastOutput)
Fields
normal: Vec2The surface normal at the hit point
point: Vec2The surface hit point
fraction: f32The fraction of the input translation at collision
iterations: i32The number of iterations used
hit: boolDid the cast hit?