pub struct LocalManifold {
pub normal: Vec2,
pub points: [LocalManifoldPoint; 2],
pub point_count: i32,
}Expand description
Contact manifold in local coordinates (frame A). (b2LocalManifold)
Fields
normal: Vec2The unit normal vector in frame A, points from shape A to shape B
points: [LocalManifoldPoint; 2]The manifold points, up to two are possible in 2D
point_count: i32The number of contact points, will be 0, 1, or 2