pub struct Manifold {
pub normal: Vec2,
pub rolling_impulse: f32,
pub points: [ManifoldPoint; 2],
pub point_count: i32,
}Expand description
A contact manifold describes the contact points between colliding shapes. (b2Manifold)
Fields
normal: Vec2The unit normal vector in world space, points from shape A to body B
rolling_impulse: f32Angular impulse applied for rolling resistance
points: [ManifoldPoint; 2]The manifold points, up to two are possible in 2D
point_count: i32The number of contact points, will be 0, 1, or 2