pub struct MassData {
pub mass: f32,
pub center: Vec2,
pub rotational_inertia: f32,
}Expand description
This holds the mass data computed for a shape. (b2MassData)
Fields
mass: f32The mass of the shape, usually in kilograms.
center: Vec2The position of the shape’s centroid relative to the shape’s origin.
rotational_inertia: f32The rotational inertia of the shape about the shape center.