Module constants

Module constants 

Constants

AABB_MARGIN_FRACTION
For small objects the margin is limited to this fraction times the maximum extent. (B2_AABB_MARGIN_FRACTION)
CONTACT_RECYCLE_COS_ANGLE
The default contact recycling world angle threshold. 0.98 ~= 11.5 degrees. (B2_CONTACT_RECYCLE_COS_ANGLE)
GRAPH_COLOR_COUNT
Maximum number of colors in the constraint graph. (B2_GRAPH_COLOR_COUNT)
MAX_ROTATION
The maximum rotation of a body per time step. Used to prevent numerical problems. (B2_MAX_ROTATION)
MAX_TASKS
Maximum number of tasks queued per world step. (B2_MAX_TASKS)
MAX_WORKERS
Maximum parallel workers. Used for some fixed size arrays. (B2_MAX_WORKERS)
MAX_WORLDS
Maximum number of simultaneous worlds that can be allocated. (B2_MAX_WORLDS)
NAME_LENGTH
Maximum length of the body name. (B2_NAME_LENGTH)
TIME_TO_SLEEP
The time that a body must be still before it will go to sleep, in seconds. (B2_TIME_TO_SLEEP)

Functions

contact_recycle_distance
The default contact recycling distance. (B2_CONTACT_RECYCLE_DISTANCE)
huge
See huge.
linear_slop
A small length used as a collision and constraint tolerance. Usually chosen to be numerically significant but visually insignificant, normally 0.5cm. (B2_LINEAR_SLOP)
max_aabb_margin
Used to fatten AABBs in the dynamic tree so proxies can move a small amount without triggering a tree adjustment, normally 5cm. (B2_MAX_AABB_MARGIN)
speculative_distance
Box2D uses limited speculative collision, normally 2cm. This reduces jitter. (B2_SPECULATIVE_DISTANCE)