max_aabb_margin

Function max_aabb_margin 

pub fn max_aabb_margin() -> f32
Used to fatten AABBs in the dynamic tree so proxies can move a small amount without triggering a tree adjustment, normally 5cm. (B2_MAX_AABB_MARGIN)

@warning modifying this can have a significant impact on performance.