pub fn contact_get_data(world: &World, contact_id: ContactId) -> ContactDataExpand description
Get the data for a contact. The manifold may have no points if the contact is not touching. (b2Contact_GetData)
pub fn contact_get_data(world: &World, contact_id: ContactId) -> ContactDataGet the data for a contact. The manifold may have no points if the contact is not touching. (b2Contact_GetData)