pub struct Contact {
pub edges: [ContactEdge; 2],
pub island_id: i32,
pub island_index: i32,
pub set_index: i32,
pub color_index: i32,
pub local_index: i32,
pub shape_id_a: i32,
pub shape_id_b: i32,
pub contact_id: i32,
pub flags: u32,
pub generation: u32,
}Expand description
Cold contact data. Used as a persistent handle and for persistent island connectivity. (b2Contact)
Fields
edges: [ContactEdge; 2]island_id: i32A contact only belongs to an island if touching, otherwise NULL_INDEX.
island_index: i32Index into the island’s contacts array for O(1) swap-removal. NULL_INDEX when not in an island.
set_index: i32index of simulation set stored in World. NULL_INDEX when slot is free.
color_index: i32index into the constraint graph color array. NULL_INDEX for non-touching or sleeping contacts, and when the slot is free.
local_index: i32contact index within set or graph color. NULL_INDEX when slot is free.
shape_id_a: i32shape_id_b: i32contact_id: i32flags: u32contact_flags bits
generation: u32Monotonically advanced when a contact is allocated in this slot. Used to check for invalid ContactId.