pub fn make_proxy(points: &[Vec2], radius: f32) -> ShapeProxyExpand description
Make a proxy for use in overlap, shape cast, and related functions. This is a deep copy of the points. (b2MakeProxy)
pub fn make_proxy(points: &[Vec2], radius: f32) -> ShapeProxyMake a proxy for use in overlap, shape cast, and related functions. This is a deep copy of the points. (b2MakeProxy)