ShapeCastPairInput

Struct ShapeCastPairInput 

pub struct ShapeCastPairInput {
    pub proxy_a: ShapeProxy,
    pub proxy_b: ShapeProxy,
    pub transform: Transform,
    pub translation_b: Vec2,
    pub max_fraction: f32,
    pub can_encroach: bool,
}
Input parameters for shape_cast. (b2ShapeCastPairInput)

Fields

proxy_a: ShapeProxy

The proxy for shape A

proxy_b: ShapeProxy

The proxy for shape B

transform: Transform

Transform of shape B in shape A’s frame, the relative pose B in A

translation_b: Vec2

The translation of shape B, in A’s frame

max_fraction: f32

The fraction of the translation to consider, typically 1

can_encroach: bool

Allows shapes with a radius to move slightly closer if already touching