pub struct Sweep {
pub local_center: Vec2,
pub c1: Vec2,
pub c2: Vec2,
pub q1: Rot,
pub q2: Rot,
}Expand description
This describes the motion of a body/shape for TOI computation. Shapes are defined with respect to the body origin, which may not coincide with the center of mass. However, to support dynamics we must interpolate the center of mass position. (b2Sweep)
Fields
local_center: Vec2Local center of mass position
c1: Vec2Starting center of mass world position
c2: Vec2Ending center of mass world position
q1: RotStarting world rotation
q2: RotEnding world rotation