Module events

Module events 

Structs

BodyMoveEvent
Body move event, triggered when a body moves due to simulation. Not reported for bodies moved by the user. (b2BodyMoveEvent)
ContactBeginTouchEvent
A begin touch event is generated when two shapes begin touching. (b2ContactBeginTouchEvent)
ContactData
The contact data for two shapes. By convention the manifold normal points from shape A to shape B. (b2ContactData)
ContactEndTouchEvent
An end touch event is generated when two shapes stop touching. (b2ContactEndTouchEvent)
ContactEvents
Contact events are buffered in the world and are available as begin/end/hit events in the current time step. These are borrowed from world storage and invalidated by the next call to world_step. (b2ContactEvents)
ContactHitEvent
A hit touch event is generated when two shapes collide faster than the hit speed threshold. (b2ContactHitEvent)
JointEvent
Joint event, reported for awake joints whose force and/or torque exceed the threshold. (b2JointEvent)
SensorBeginTouchEvent
A begin touch event is generated when a shape starts to overlap a sensor shape. (b2SensorBeginTouchEvent)
SensorEndTouchEvent
An end touch event is generated when a shape stops overlapping a sensor shape. Always confirm the shape id is valid before use — either shape may have been destroyed. (b2SensorEndTouchEvent)
SensorEvents
Sensor events are buffered in the world and are available as begin/end events in the current time step. These are borrowed from world storage and invalidated by the next call to world_step. (b2SensorEvents)