pub struct ContactBeginTouchEvent {
pub shape_id_a: ShapeId,
pub shape_id_b: ShapeId,
pub contact_id: ContactId,
}Expand description
A begin touch event is generated when two shapes begin touching. (b2ContactBeginTouchEvent)
Fields
shape_id_a: ShapeIdId of the first shape
shape_id_b: ShapeIdId of the second shape
contact_id: ContactIdThe transient contact id. May be destroyed automatically when the world is modified or simulated.