pub struct SensorBeginTouchEvent {
pub sensor_shape_id: ShapeId,
pub visitor_shape_id: ShapeId,
}Expand description
A begin touch event is generated when a shape starts to overlap a sensor shape. (b2SensorBeginTouchEvent)
Fields
sensor_shape_id: ShapeIdThe id of the sensor shape
visitor_shape_id: ShapeIdThe id of the shape that began touching the sensor shape