pub struct SensorEndTouchEvent {
pub sensor_shape_id: ShapeId,
pub visitor_shape_id: ShapeId,
}Expand description
An end touch event is generated when a shape stops overlapping a sensor shape. Always confirm the shape id is valid before use — either shape may have been destroyed. (b2SensorEndTouchEvent)
Fields
sensor_shape_id: ShapeIdThe id of the sensor shape. @warning may have been destroyed
visitor_shape_id: ShapeIdThe id of the shape that stopped touching. @warning may have been destroyed