SensorEvents

Struct SensorEvents 

pub struct SensorEvents<'a> {
    pub begin_events: &'a [SensorBeginTouchEvent],
    pub end_events: &'a [SensorEndTouchEvent],
}
Sensor events are buffered in the world and are available as begin/end events in the current time step. These are borrowed from world storage and invalidated by the next call to world_step. (b2SensorEvents)

Fields

begin_events: &'a [SensorBeginTouchEvent]

Events for shapes that began overlapping a sensor this step.

end_events: &'a [SensorEndTouchEvent]

Events for shapes that stopped overlapping a sensor. These are from the previous buffer so the user doesn’t need to flush events mid-step.