pub fn compute_fat_shape_aabb(
geometry: &ShapeGeometry,
xf: WorldTransform,
extra: f32,
) -> AabbExpand description
Compute a fattened bounding box of a transformed shape. (b2ComputeFatShapeAABB)
pub fn compute_fat_shape_aabb(
geometry: &ShapeGeometry,
xf: WorldTransform,
extra: f32,
) -> AabbCompute a fattened bounding box of a transformed shape. (b2ComputeFatShapeAABB)