pub fn compute_segment_aabb(shape: &Segment, xf: WorldTransform) -> AabbExpand description
Compute the bounding box of a transformed line segment. (b2ComputeSegmentAABB)
pub fn compute_segment_aabb(shape: &Segment, xf: WorldTransform) -> AabbCompute the bounding box of a transformed line segment. (b2ComputeSegmentAABB)