Module hull

Module hull 

Structs

Hull
A convex hull. Used to construct convex polygons. (b2Hull)

Constants

MAX_POLYGON_VERTICES
The maximum number of vertices on a convex polygon. Changing this affects performance even if you don’t use more vertices. (B2_MAX_POLYGON_VERTICES)

Functions

compute_hull
Compute the convex hull of a set of points. Returns an empty hull if it fails. (b2ComputeHull)
validate_hull
Validate that a hull is convex, CCW, and has no collinear points. (b2ValidateHull)