Island

Struct Island 

pub struct Island {
    pub set_index: i32,
    pub local_index: i32,
    pub island_id: i32,
    pub constraint_remove_count: i32,
    pub bodies: Vec<i32>,
    pub contacts: Vec<ContactLink>,
    pub joints: Vec<JointLink>,
}
Persistent island for awake bodies, joints, and contacts. Contacts are touching. Contacts and joints may connect to static bodies, but static bodies are not in the island. (b2Island)

https://en.wikipedia.org/wiki/Component_(graph_theory) https://en.wikipedia.org/wiki/Dynamic_connectivity

Fields

set_index: i32

index of solver set stored in World. May be NULL_INDEX.

local_index: i32

island index within set. May be NULL_INDEX.

island_id: i32constraint_remove_count: i32

How many contacts have been removed from this island. Used to determine if an island is a candidate for splitting.

bodies: Vec<i32>contacts: Vec<ContactLink>

Contacts and joints that belong to this island. May connect to static bodies not in the island. Each link carries the two body ids so island splitting’s union-find never needs to touch Contact/Joint.

joints: Vec<JointLink>