pub struct JointEdge {
pub body_id: i32,
pub prev_key: i32,
pub next_key: i32,
}Expand description
A joint edge connects bodies and joints together in a joint graph where each body is a node and each joint is an edge. (b2JointEdge)
Fields
body_id: i32prev_key: i32next_key: i32Trait Implementations
impl Copy for JointEdge
impl Eq for JointEdge
impl StructuralPartialEq for JointEdge