pub fn offset_world_transform(a: WorldTransform, b: Transform) -> WorldTransformExpand description
Convert a local transform B into world space using world transform A.
pub fn offset_world_transform(a: WorldTransform, b: Transform) -> WorldTransformConvert a local transform B into world space using world transform A.