pub fn to_relative_transform(t: WorldTransform, base: Pos) -> TransformExpand description
Shift a world transform into the frame of a base position.
pub fn to_relative_transform(t: WorldTransform, base: Pos) -> TransformShift a world transform into the frame of a base position.