Module mover

Module mover 

Structs

CollisionPlane
A collision plane that can be fed to solve_planes. Normally assembled by the user from the plane results of world_collide_mover. (b2CollisionPlane)
PlaneSolverResult
Result returned by solve_planes. (b2PlaneSolverResult)

Functions

clip_vector
Clips the velocity against the given planes so the mover doesn’t keep pushing into what it already touched. (b2ClipVector)
solve_planes
Solves the position of a mover that satisfies the given collision planes.