solve_planes

Function solve_planes 

pub fn solve_planes(
    target_delta: Vec2,
    planes: &mut [CollisionPlane],
) -> PlaneSolverResult
Solves the position of a mover that satisfies the given collision planes.

target_delta is the desired movement from the position used to generate the collision planes. (b2SolvePlanes)