pub struct CollisionPlane {
pub plane: Plane,
pub push_limit: f32,
pub push: f32,
pub clip_velocity: bool,
}Expand description
A collision plane that can be fed to solve_planes. Normally assembled
by the user from the plane results of world_collide_mover.
(b2CollisionPlane)
Fields
plane: PlaneThe collision plane between the mover and some shape
push_limit: f32Setting this to f32::MAX makes the plane as rigid as possible. Lower values can make the plane collision soft. Usually in meters.
push: f32The push on the mover determined by solve_planes. Usually in
meters.
clip_velocity: boolIndicates if clip_vector should clip against this plane. Should be
false for soft collision.