pub struct SnapHeader {
pub magic: u32,
pub version: u32,
pub layout_hash: u32,
pub flags: u32,
}Expand description
Snapshot image header. (b2SnapHeader)
Fields
magic: u32version: u32layout_hash: u32flags: u32Implementations
Sourceimpl SnapHeader
impl SnapHeader
pub const SIZE: usize = 16
Sourcepub fn current() -> SnapHeader
pub fn current() -> SnapHeader
Header for an image produced by this build.
pub fn write(&self, buf: &mut Vec<u8>)
Sourcepub fn is_compatible(&self) -> bool
pub fn is_compatible(&self) -> bool
True when an image with this header can be restored by this build. The validation flag is diagnostic only, exactly like C.