chain_get_segments

Function chain_get_segments 

pub fn chain_get_segments(
    world: &World,
    chain_id: ChainId,
    capacity: usize,
) -> Vec<ShapeId>
Get the segment shape ids for a chain, up to capacity. (b2Chain_GetSegments — returns a Vec instead of filling a caller array)