shape_get_parent_chain

Function shape_get_parent_chain 

pub fn shape_get_parent_chain(world: &World, shape_id: ShapeId) -> ChainId
Get the parent chain id if the shape type is a chain segment, otherwise returns the null chain id. (b2Shape_GetParentChain)