shape_set_filter

Function shape_set_filter 

pub fn shape_set_filter(world: &mut World, shape_id: ShapeId, filter: Filter)
Set the current filter. This is almost as expensive as recreating the shape. Sensor overlaps are not updated until the next time step. (b2Shape_SetFilter)