pub enum BodyType {
Static = 0,
Kinematic = 1,
Dynamic = 2,
}Expand description
The body simulation type. Each body is one of these three types. (b2BodyType)
Variants
Static = 0
zero mass, zero velocity, may be manually moved
Kinematic = 1
zero mass, velocity set by user, moved by solver
Dynamic = 2
positive mass, velocity determined by forces, moved by solver