JointDef

Struct JointDef 

pub struct JointDef {
    pub user_data: u64,
    pub body_id_a: BodyId,
    pub body_id_b: BodyId,
    pub local_frame_a: Transform,
    pub local_frame_b: Transform,
    pub force_threshold: f32,
    pub torque_threshold: f32,
    pub constraint_hertz: f32,
    pub constraint_damping_ratio: f32,
    pub draw_scale: f32,
    pub collide_connected: bool,
}
Base joint definition used by all joint types. The local frames are measured from the body’s origin rather than the center of mass because:

  1. you might not know where the center of mass will be
  2. if you add/remove shapes from a body and recompute the mass, the joints will be broken

(b2JointDef)

Fields

user_data: u64

User data

body_id_a: BodyId

The first attached body

body_id_b: BodyId

The second attached body

local_frame_a: Transform

The first local joint frame

local_frame_b: Transform

The second local joint frame

force_threshold: f32

Force threshold for joint events

torque_threshold: f32

Torque threshold for joint events

constraint_hertz: f32

Constraint hertz (advanced feature)

constraint_damping_ratio: f32

Constraint damping ratio (advanced feature)

draw_scale: f32

Debug draw scale

collide_connected: bool

Set this flag to true if the attached bodies should collide