pub struct WheelJointDef {
pub base: JointDef,
pub enable_spring: bool,
pub hertz: f32,
pub damping_ratio: f32,
pub enable_limit: bool,
pub lower_translation: f32,
pub upper_translation: f32,
pub enable_motor: bool,
pub max_motor_torque: f32,
pub motor_speed: f32,
pub internal_value: i32,
}Expand description
Wheel joint definition. Body B is a wheel that may rotate freely and slide along the local x-axis in frame A. The joint translation is zero when the local frame origins coincide in world space. (b2WheelJointDef)
Fields
base: JointDefBase joint definition
enable_spring: boolEnable a linear spring along the local axis
hertz: f32Spring stiffness in Hertz
damping_ratio: f32Spring damping ratio, non-dimensional
enable_limit: boolEnable/disable the joint linear limit
lower_translation: f32The lower translation limit
upper_translation: f32The upper translation limit
enable_motor: boolEnable/disable the joint rotational motor
max_motor_torque: f32The maximum motor torque, typically in newton-meters
motor_speed: f32The desired motor speed in radians per second
internal_value: i32Used internally to detect a valid definition. DO NOT SET.