pub struct PlaneResult {
pub plane: Plane,
pub point: Vec2,
pub hit: bool,
}Expand description
These are the collision planes returned from b2World_CollideMover. The plane and point are relative to the query origin, matching the mover capsule. (b2PlaneResult)
Fields
plane: PlaneThe collision plane between the mover and a convex shape
point: Vec2The collision point on the shape.
hit: boolDid the collision register a hit? If not this plane should be ignored.