pub fn linear_slop() -> f32Expand description
A small length used as a collision and constraint tolerance. Usually chosen to be numerically significant but visually insignificant, normally 0.5cm. (B2_LINEAR_SLOP)
@warning modifying this can have a significant impact on stability.