This keeps constraints involving two dynamic bodies at a lower solver
priority than constraints involving a dynamic and static bodies. This
reduces tunneling due to push through. (B2_DYNAMIC_COLOR_COUNT)
This holds constraints that cannot fit the graph color limit. This happens
when a single dynamic body is touching many other bodies. (B2_OVERFLOW_INDEX)