A distance proxy used by the GJK algorithm. It encapsulates any shape.
You can provide between 1 and MAX_POLYGON_VERTICES points and a radius.
(b2ShapeProxy)
Used to warm start the GJK simplex. If you call this function multiple times
with nearby transforms this might improve performance. Otherwise you can
zero initialize this. (b2SimplexCache)
This describes the motion of a body/shape for TOI computation. Shapes are
defined with respect to the body origin, which may not coincide with the
center of mass. However, to support dynamics we must interpolate the center
of mass position. (b2Sweep)
Perform a linear shape cast of shape B moving and shape A fixed. Determines
the hit point, normal, and translation fraction. The query runs in frame A,
so the hit point and normal are returned in frame A. Initially touching
shapes are a miss unless can_encroach allows it. (b2ShapeCast)
Compute the closest points between two shapes represented as point clouds.
The cache is input/output: on the first call set SimplexCache::count to
zero. (b2ShapeDistance)
Compute the upper bound on time before two shapes penetrate. Time is
represented as a fraction between [0, max_fraction]. This uses a swept
separating axis and may miss some intermediate, non-tunneling collisions.
If you change the time interval, you should call this function again.
(b2TimeOfImpact)