Skip to main content Module events Copy item path Source BodyMoveEvent Body move event, triggered when a body moves due to simulation. Not
reported for bodies moved by the user. (b2BodyMoveEvent) ContactBeginTouchEvent A begin touch event is generated when two shapes begin touching.
(b2ContactBeginTouchEvent) ContactData The contact data for two shapes. By convention the manifold normal points
from shape A to shape B. (b2ContactData) ContactEndTouchEvent An end touch event is generated when two shapes stop touching.
(b2ContactEndTouchEvent) ContactHitEvent A hit touch event is generated when two shapes collide faster than the hit
speed threshold. (b2ContactHitEvent) JointEvent Joint event, reported for awake joints whose force and/or torque exceed the
threshold. (b2JointEvent) SensorBeginTouchEvent A begin touch event is generated when a shape starts to overlap a sensor
shape. (b2SensorBeginTouchEvent) SensorEndTouchEvent An end touch event is generated when a shape stops overlapping a sensor
shape. Always confirm the shape id is valid before use — either shape may
have been destroyed. (b2SensorEndTouchEvent)