pub struct ContactEvents<'a> {
pub begin_events: &'a [ContactBeginTouchEvent],
pub end_events: &'a [ContactEndTouchEvent],
pub hit_events: &'a [ContactHitEvent],
}Expand description
Contact events are buffered in the world and are available as begin/end/hit
events in the current time step. These are borrowed from world storage and
invalidated by the next call to world_step. (b2ContactEvents)
Fields
begin_events: &'a [ContactBeginTouchEvent]Events for shapes that began touching this step.
end_events: &'a [ContactEndTouchEvent]Events for shapes that stopped touching. These are from the previous buffer so the user doesn’t need to flush events mid-step.
hit_events: &'a [ContactHitEvent]Events for impacts above the hit-event threshold.