Skip to main content Module geometry Copy item path Source collide_mover_and_capsule Collide a mover capsule against a capsule. (b2CollideMoverAndCapsule) collide_mover_and_circle Collide a mover capsule against a circle. (b2CollideMoverAndCircle) collide_mover_and_polygon Collide a mover capsule against a polygon. (b2CollideMoverAndPolygon) collide_mover_and_segment Collide a mover capsule against a segment. (b2CollideMoverAndSegment) compute_capsule_aabb Compute the bounding box of a transformed capsule. (b2ComputeCapsuleAABB) compute_capsule_mass Compute mass properties of a capsule. (b2ComputeCapsuleMass) compute_circle_aabb Compute the bounding box of a transformed circle. (b2ComputeCircleAABB) compute_circle_mass Compute mass properties of a circle. (b2ComputeCircleMass) compute_fat_shape_aabb Compute a fattened bounding box of a transformed shape. (b2ComputeFatShapeAABB) compute_polygon_aabb Compute the bounding box of a transformed polygon. (b2ComputePolygonAABB) compute_polygon_mass Compute mass properties of a polygon. (b2ComputePolygonMass) compute_segment_aabb Compute the bounding box of a transformed line segment. (b2ComputeSegmentAABB) is_valid_ray Validate ray cast input data (NaN, etc). (b2IsValidRay) make_box Make a box (rectangle) polygon, bypassing the need for a convex hull.
(b2MakeBox) make_offset_box Make an offset box, bypassing the need for a convex hull. (b2MakeOffsetBox) make_offset_polygon Make an offset convex polygon from a convex hull. This will assert if the
hull is not valid. (b2MakeOffsetPolygon) make_offset_rounded_box Make an offset rounded box, bypassing the need for a convex hull.
(b2MakeOffsetRoundedBox) make_offset_rounded_polygon Make an offset rounded convex polygon from a convex hull. This will assert
if the hull is not valid. (b2MakeOffsetRoundedPolygon) make_polygon Make a convex polygon from a convex hull. This will assert if the hull is
not valid. (b2MakePolygon) make_rounded_box Make a rounded box, bypassing the need for a convex hull. (b2MakeRoundedBox) make_square Make a square polygon, bypassing the need for a convex hull. (b2MakeSquare) point_in_capsule Test a point for overlap with a capsule in local space. (b2PointInCapsule) point_in_circle Test a point for overlap with a circle in local space. (b2PointInCircle) point_in_polygon Test a point for overlap with a convex polygon in local space.
(b2PointInPolygon) ray_cast_capsule Ray cast versus capsule shape in local space. (b2RayCastCapsule) ray_cast_circle Ray cast versus circle shape in local space. (b2RayCastCircle) ray_cast_polygon Ray cast versus polygon shape in local space. (b2RayCastPolygon) ray_cast_segment Ray cast versus segment shape in local space. Optionally treat the segment
as one-sided with hits from the left side being treated as a miss.
(b2RayCastSegment) shape_cast_capsule Shape cast versus a capsule. (b2ShapeCastCapsule) shape_cast_circle Shape cast versus a circle. (b2ShapeCastCircle) shape_cast_polygon Shape cast versus a convex polygon. (b2ShapeCastPolygon) shape_cast_segment Shape cast versus a line segment. (b2ShapeCastSegment) transform_polygon Transform a polygon. This is useful for transferring a shape from one body
to another. (b2TransformPolygon)