pub fn make_offset_rounded_polygon(
hull: &Hull,
position: Vec2,
rotation: Rot,
radius: f32,
) -> PolygonExpand description
Make an offset rounded convex polygon from a convex hull. This will assert if the hull is not valid. (b2MakeOffsetRoundedPolygon)