make_polygon

Function make_polygon 

pub fn make_polygon(hull: &Hull, radius: f32) -> Polygon
Make a convex polygon from a convex hull. This will assert if the hull is not valid. (b2MakePolygon)

@warning Do not manually fill in the hull data, it must come directly from compute_hull.