Sensor

Struct Sensor 

pub struct Sensor {
    pub hits: Vec<Visitor>,
    pub overlaps1: Vec<Visitor>,
    pub overlaps2: Vec<Visitor>,
    pub shape_id: i32,
}
Sensors are shapes that live in the broad-phase but never have contacts. At the end of the time step all sensors are queried for overlap with any other shapes. Sensors ignore body type and sleeping. Sensors generate events when a new overlap appears or an overlap disappears. (b2Sensor)

Fields

hits: Vec<Visitor>overlaps1: Vec<Visitor>overlaps2: Vec<Visitor>shape_id: i32

Implementations

Source

impl Sensor

pub fn new(shape_id: i32) -> Sensor