Module shape

Module shape 

Structs

ChainShape
Internal chain shape. (b2ChainShape)
Shape
Internal shape. (b2Shape)
ShapeExtent
(b2ShapeExtent)

Functions

collide_mover
(b2CollideMover)
compute_shape_aabb
(b2ComputeShapeAABB)
compute_shape_extent
(b2ComputeShapeExtent)
compute_shape_mass
(b2ComputeShapeMass)
create_capsule_shape
(b2CreateCapsuleShape)
create_chain_segment_shape
(b2CreateChainSegmentShape)
create_circle_shape
(b2CreateCircleShape)
create_polygon_shape
(b2CreatePolygonShape)
create_segment_shape
(b2CreateSegmentShape)
create_shape_proxy
(b2CreateShapeProxy)
destroy_shape
Destroy a shape by id, optionally updating the body mass. (b2DestroyShape)
destroy_shape_proxy
(b2DestroyShapeProxy)
get_shape_centroid
(b2GetShapeCentroid)
get_shape_index
Validate a ShapeId and return the raw shape index. (b2GetShape — C returns a pointer; Rust returns the index into world.shapes)
get_shape_perimeter
(b2GetShapePerimeter)
get_shape_projected_perimeter
This projects the shape perimeter onto an infinite line. (b2GetShapeProjectedPerimeter)
make_shape_distance_proxy
(b2MakeShapeDistanceProxy)
ray_cast_shape
(b2RayCastShape)
shape_cast_shape
(b2ShapeCastShape)
should_query_collide
(static inline b2ShouldQueryCollide)
should_shapes_collide
(static inline b2ShouldShapesCollide)