Structs
- Chain
Shape - Internal chain shape. (b2ChainShape)
- Shape
- Internal shape. (b2Shape)
- Shape
Extent - (b2ShapeExtent)
Functions
- collide_
mover - (b2CollideMover)
- compute_
shape_ aabb - (b2ComputeShapeAABB)
- compute_
shape_ extent - (b2ComputeShapeExtent)
- compute_
shape_ mass - (b2ComputeShapeMass)
- create_
capsule_ shape - (b2CreateCapsuleShape)
- create_
chain_ segment_ shape - (b2CreateChainSegmentShape)
- create_
circle_ shape - (b2CreateCircleShape)
- create_
polygon_ shape - (b2CreatePolygonShape)
- create_
segment_ shape - (b2CreateSegmentShape)
- create_
shape_ proxy - (b2CreateShapeProxy)
- destroy_
shape - Destroy a shape by id, optionally updating the body mass. (b2DestroyShape)
- destroy_
shape_ proxy - (b2DestroyShapeProxy)
- get_
shape_ centroid - (b2GetShapeCentroid)
- get_
shape_ index - Validate a ShapeId and return the raw shape index. (b2GetShape — C returns
a pointer; Rust returns the index into
world.shapes) - get_
shape_ perimeter - (b2GetShapePerimeter)
- get_
shape_ projected_ perimeter - This projects the shape perimeter onto an infinite line. (b2GetShapeProjectedPerimeter)
- make_
shape_ distance_ proxy - (b2MakeShapeDistanceProxy)
- ray_
cast_ shape - (b2RayCastShape)
- shape_
cast_ shape - (b2ShapeCastShape)
- should_
query_ collide - (static inline b2ShouldQueryCollide)
- should_
shapes_ collide - (static inline b2ShouldShapesCollide)