shape_set_chain_segment

Function shape_set_chain_segment 

pub fn shape_set_chain_segment(
    world: &mut World,
    shape_id: ShapeId,
    chain_segment: &ChainSegment,
)
Allows you to change a shape to be a stand-alone chain segment or update the current one. Cannot be used on a segment owned by a chain shape. (b2Shape_SetChainSegment)