The index of the first sleeping set. Each island that goes to sleep is put
into a sleeping set holding all bodies, contacts, and joints from that
island, making it very efficient to wake a single island.
This is called when joints are created between sets. I want to allow the
sets to continue sleeping if both are asleep. Otherwise one set is waked.
Islands will get merged when the set is waked. (b2MergeSolverSets)