RevoluteJointDef

Struct RevoluteJointDef 

pub struct RevoluteJointDef {
    pub base: JointDef,
    pub target_angle: f32,
    pub enable_spring: bool,
    pub hertz: f32,
    pub damping_ratio: f32,
    pub enable_limit: bool,
    pub lower_angle: f32,
    pub upper_angle: f32,
    pub enable_motor: bool,
    pub max_motor_torque: f32,
    pub motor_speed: f32,
    pub internal_value: i32,
}
Revolute joint definition. A point on body B is fixed to a point on body A. Allows relative rotation. (b2RevoluteJointDef)

Fields

base: JointDef

Base joint definition

target_angle: f32

The target angle for the joint in radians. The spring-damper will drive to this angle.

enable_spring: bool

Enable a rotational spring on the revolute hinge axis

hertz: f32

The spring stiffness Hertz, cycles per second

damping_ratio: f32

The spring damping ratio, non-dimensional

enable_limit: bool

A flag to enable joint limits

lower_angle: f32

The lower angle for the joint limit in radians. Minimum of -0.99*pi radians.

upper_angle: f32

The upper angle for the joint limit in radians. Maximum of 0.99*pi radians.

enable_motor: bool

A flag to enable the joint motor

max_motor_torque: f32

The maximum motor torque, typically in newton-meters

motor_speed: f32

The desired motor speed in radians per second

internal_value: i32

Used internally to detect a valid definition. DO NOT SET.