world_set_gravity

Function world_set_gravity 

pub fn world_set_gravity(world: &mut World, gravity: Vec2)
Set the gravity vector for the entire world. Box2D has no concept of an up direction and this is left as a decision for the application. (b2World_SetGravity)