pub struct TaskContext {
pub sensor_hits: Vec<SensorHit>,
pub contact_state_bit_set: BitSet,
pub hit_event_bit_set: BitSet,
pub has_hit_events: bool,
pub joint_state_bit_set: BitSet,
pub enlarged_sim_bit_set: BitSet,
pub awake_island_bit_set: BitSet,
pub split_sleep_time: f32,
pub split_island_id: i32,
pub recycled_contact_count: i32,
}Expand description
Per thread task storage. (b2TaskContext)
Fields
sensor_hits: Vec<SensorHit>Collect per thread sensor continuous hit events.
contact_state_bit_set: BitSetThese bits align with the contact id capacity and signal a change in contact status.
hit_event_bit_set: BitSetThese bits align with the contact id capacity and signal a hit event.
has_hit_events: boolFast-path flag: true when this worker set at least one bit in hit_event_bit_set this step.
joint_state_bit_set: BitSetThese bits align with the joint id capacity and signal a change in joint status.
enlarged_sim_bit_set: BitSetUsed to track bodies with shapes that have enlarged AABBs. This avoids a bit array that is very large when there are many static shapes.
awake_island_bit_set: BitSetUsed to put islands to sleep.
split_sleep_time: f32Per worker split island candidate.
split_island_id: i32recycled_contact_count: i32Number of contacts recycled this step (collide pass).